API Reference
================

Core Components
------------------

LLM
~~~

.. autoclass:: yamllm.core.llm.LLM
   :members:
   :undoc-members:
   :special-members: __init__

Configuration
----------------

.. autoclass:: yamllm.core.config.Config
   :members:
   :undoc-members:
   :special-members: __init__
   :no-index:

Memory Management
--------------------

.. autoclass:: yamllm.memory.conversation_store.ConversationStore
   :members:
   :undoc-members:

.. autoclass:: yamllm.memory.conversation_store.VectorStore
   :members:
   :undoc-members:

